@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2022-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2022-2025 Brett Sheffield <bacs@librecast.net> */
 
 #include <lcrq_pvt.h>
 #include <arpa/inet.h>
@@ -1047,7 +1047,7 @@ rq_t *rq_init(const uint64_t F, const uint16_t T)
 {
 	rq_t *rq;
 
-	assert(F); assert(F <= 946270874880);
+	assert(F <= 946270874880);
 	assert(T); assert(T % RQ_AL == 0);
 
 	rq = malloc(sizeof(rq_t));
@@ -1066,7 +1066,9 @@ rq_t *rq_init(const uint64_t F, const uint16_t T)
 	rq->Nmax = rq->T/(rq->SS*rq->Al);
 	rq->Kt = CEIL(rq->F,rq->T);
 	rq->kl = KL(rq->WS, rq->Al, rq->T, rq->Nmax);
-	rq->Z = CEIL(rq->Kt,rq->kl);
+	rq->Z = MAX(1, CEIL(rq->Kt,rq->kl));
+
+	assert(rq->Z);
 
 	/* N is the minimum n=1, ..., Nmax such that ceil(Kt/Z) <= KL(n) */
 	for (rq->N = 1; rq->N <= rq->Nmax; rq->N++) {
